Adapters
========

.. automodule:: linkml_store.api.stores
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 2

   linkml_store.api.stores.duckdb
   linkml_store.api.stores.mongodb
   linkml_store.api.stores.filesystem
   linkml_store.api.stores.solr
   linkml_store.api.stores.hdf5
   linkml_store.api.stores.chromadb
   linkml_store.api.stores.neo4j
